---
title: Why TreadI?
nav_order: 1
---

<p align="center">
<img src="{{site.baseurl}}/images/treadi_logo.svg" alt="logo life ring resembling github issue icon" width="256"/>
</p>

Are you a maintainer on many Github repositories?
Do have a backlog of issues and pull requests that you're struggling to make progress on?

If you're drowining in issues and pull requests, TreadI helps you keep your head above water.

TreadI shows you the **5** most recently updated issues and pull requests across all of your repositories.

Why **5**?
**5** is just at the limit of [subitizing](https://en.wikipedia.org/wiki/Subitizing).
That means the list doesn't feel overwhelming to look at, and it becomes much easier to pick something to work on.

Try it out!
[Install TreadI](./install.html), and then follow the [Getting Started guide](./getting-started.html).